@@ -3,12 +3,12 @@ package File::Listing::Ftpcopy;
 use strict;
 use warnings;
 use v5.10.1;
-use Exporter;
+use base qw( Exporter );
 use Carp qw( croak );
 use Time::Local qw( timelocal );
 
 # ABSTRACT: parse directory listing using ftpparse from ftpcopy
-our $VERSION = '0.02_02'; # VERSION
+our $VERSION = '0.01'; # VERSION
 
 
 sub parse_dir ($;$$$)
@@ -93,7 +93,6 @@ sub parse_dir ($;$$$)
 }
 
 
-our @ISA = qw( Exporter );
 our @EXPORT = qw( parse_dir );
 
 our %EXPORT_TAGS = (all => [qw(
@@ -154,7 +153,7 @@ File::Listing::Ftpcopy - parse directory listing using ftpparse from ftpcopy
 
 =head1 VERSION
 
-version 0.02_02
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -180,8 +179,8 @@ version 0.02_02
    chomp $line;
    my $h = ftpparse($line);
    next unless defined $h;
-   say "name : ", $h->{name}
-   say "size : ", $h->{size} if $h->{sizetype} != SIZE_UNKNOWN;
+   say "name : $h{name}";
+   say "size : $h{size}" if $h{sizetype} != SIZE_UNKNOWN;
  }
 
 =head1 DESCRIPTION
@@ -427,9 +426,6 @@ time zone is unknown
 
 =head1 CAVEATS
 
-Because C<ftpparse> is written in C and the bindings to it are in XS, so a C compiler
-is required.
-
 Because C<ftpparse> does not parse out permission information, the mode field is
 always undef.
 
